@@ -25,6 +25,10 @@ class MetricDistance(Projection):
         Atom selection string for the second set of atoms. If sel1 != sel2, it will calculate inter-set distances.
         If sel1 == sel2, it will calculate intra-set distances.
         See more `here <http://www.ks.uiuc.edu/Research/vmd/vmd-1.9.2/ug/node89.html>`__
+    periodic : str
+        If periodic distances should be calculated and between which elements. If set to "chains" it will only calculate
+        periodic distances between different chains. If set to "selections" it will calculate periodic distances between
+        the two selections. If set to None it will not calculate any periodic distances.
     groupsel1 : ['all','residue'], optional
         Group all atoms in `sel1` to the single minimum distance. Alternatively can calculate the minimum distance of a
         residue containing the atoms in sel1.
@@ -34,8 +38,6 @@ class MetricDistance(Projection):
         Set to 'contacts' to calculate contacts instead of distances
     threshold : float, optional
         The threshold under which a distance is considered in contact. Units in Angstrom.
-    pbc : bool, optional
-        Set to false to disable distance calculations using periodic distances
     truncate : float, optional
         Set all distances larger than `truncate` to `truncate`. Units in Angstrom.
     update :
@@ -50,22 +52,33 @@ class MetricDistance(Projection):
         self,
         sel1,
         sel2,
+        periodic,
         groupsel1=None,
         groupsel2=None,
         metric="distances",
         threshold=8,
-        pbc=True,
+        pbc=None,
         truncate=None,
     ):
         super().__init__()
 
+        if pbc is not None:
+            raise DeprecationWarning(
+                "The pbc option in MetricDistance is deprecated. Please use the `periodic` option to specify which periodic distances should be calculated."
+            )
+
         self.sel1 = sel1
         self.sel2 = sel2
+        self.periodic = periodic
+        if periodic is not None and periodic not in ["chains", "selections"]:
+            raise RuntimeError(
+                "Option `periodic` can only be None, 'chains' or 'selections'."
+            )
+
         self.groupsel1 = groupsel1
         self.groupsel2 = groupsel2
         self.metric = metric
         self.threshold = threshold
-        self.pbc = pbc
         self.truncate = truncate
 
     def _checkChains(self, mol, sel1, sel2):
@@ -102,7 +115,7 @@ class MetricDistance(Projection):
         getMolProp = lambda prop: self._getMolProp(mol, prop)
         sel1 = getMolProp("sel1")
         sel2 = getMolProp("sel2")
-        if self.pbc:
+        if self.periodic == "chains":
             self._checkChains(mol, sel1, sel2)
 
         if np.ndim(sel1) == 1 and np.ndim(sel2) == 1:  # normal distances
@@ -110,9 +123,9 @@ class MetricDistance(Projection):
                 mol,
                 sel1,
                 sel2,
+                self.periodic,
                 self.metric,
                 self.threshold,
-                self.pbc,
                 truncate=self.truncate,
             )
         else:  # minimum distances by groups
@@ -120,9 +133,9 @@ class MetricDistance(Projection):
                 mol,
                 sel1,
                 sel2,
+                self.periodic,
                 self.metric,
                 self.threshold,
-                pbc=self.pbc,
                 truncate=self.truncate,
             )
 
@@ -138,7 +151,12 @@ class MetricDistance(Projection):
         return res
 
     def _processSelection(self, mol, sel, groupsel):
-        if isinstance(sel, str):  # If user passes simple string selections
+        # If user passes simple string selections or 1D array of ints or bools
+        if isinstance(sel, str) or (
+            isinstance(sel, np.ndarray)
+            and sel.ndim == 1
+            and (np.issubdtype(sel.dtype, np.integer) or sel.dtype == bool)
+        ):
             if groupsel is None:
                 sel = mol.atomselect(sel)
             elif groupsel == "all":
@@ -147,8 +165,14 @@ class MetricDistance(Projection):
                 sel = self._groupByResidue(mol, sel)
             else:
                 raise NameError("Invalid groupsel argument")
-        else:  # If user passes his own sets of groups
+        elif isinstance(sel, np.ndarray) or isinstance(
+            sel, list
+        ):  # If user passes his own sets of groups
             sel = self._processMultiSelections(mol, sel)
+        else:
+            raise RuntimeError(
+                "Invalid atom selection. Either provide a string, a list of string, a 1D numpy array (int/bool) or a 2D numpy array for groups."
+            )
 
         if np.sum(sel) == 0:
             raise NameError("Selection returned 0 atoms")
@@ -157,7 +181,14 @@ class MetricDistance(Projection):
     def _processMultiSelections(self, mol, sel):
         newsel = np.zeros((len(sel), mol.numAtoms), dtype=bool)
         for s in range(len(sel)):
-            newsel[s, :] = mol.atomselect(sel[s])
+            if isinstance(sel[s], str):
+                newsel[s, :] = mol.atomselect(sel[s])
+            elif isinstance(sel[s], np.ndarray) and (
+                np.issubdtype(sel[s].dtype, np.integer) or sel[s].dtype == bool
+            ):
+                newsel[s, sel[s]] = True
+            else:
+                raise RuntimeError("Invalid selection provided for groups")
         return newsel
 
     def _groupByResidue(self, mol, sel):
@@ -258,7 +289,8 @@ class MetricSelfDistance(MetricDistance):
         groupsel=None,
         metric="distances",
         threshold=8,
-        pbc=True,
+        periodic=None,
+        pbc=None,
         truncate=None,
     ):
         """ Creates a MetricSelfDistance object
@@ -275,8 +307,8 @@ class MetricSelfDistance(MetricDistance):
             Set to 'contacts' to calculate contacts instead of distances
         threshold : float, optional
             The threshold under which a distance is considered in contact
-        pbc : bool, optional
-            Set to false to disable distance calculations using periodic distances
+        periodic : str
+            See documentation of MetricDistance class
         truncate : float, optional
             Set all distances larger than `truncate` to `truncate`
         update :
@@ -286,7 +318,21 @@ class MetricSelfDistance(MetricDistance):
         -------
         proj : MetricDistance object
         """
-        super().__init__(sel, sel, groupsel, groupsel, metric, threshold, pbc, truncate)
+        if pbc is not None:
+            raise DeprecationWarning(
+                "The `pbc` option is deprecated please use the `periodic` option as described in MetricDistance."
+            )
+
+        super().__init__(
+            sel1=sel,
+            sel2=sel,
+            periodic=periodic,
+            groupsel1=groupsel,
+            groupsel2=groupsel,
+            metric=metric,
+            threshold=threshold,
+            truncate=truncate,
+        )
 
 
 def contactVecToMatrix(vector, atomIndexes):
@@ -477,7 +523,11 @@ class _TestMetricDistance(unittest.TestCase):
 
     def test_contacts(self):
         metr = MetricDistance(
-            "protein and name CA", "resname MOL and noh", metric="contacts", threshold=8
+            "protein and name CA",
+            "resname MOL and noh",
+            periodic="selections",
+            metric="contacts",
+            threshold=8,
         )
         data = metr.project(self.mol)
         reffile = os.path.join(
@@ -487,6 +537,54 @@ class _TestMetricDistance(unittest.TestCase):
 
         assert np.allclose(data, refdata, atol=1e-3), "Contact calculation is broken"
 
+    def test_atomselects(self):
+        # String atomselection
+        metr = MetricSelfDistance("protein and name CA", metric="contacts", threshold=8)
+        data = metr.project(self.mol_skipped)
+        mapping = metr.getMapping(self.mol_skipped)
+        assert data.shape == (20, 38226) and mapping.shape == (38226, 3)
+
+        # Integer index atomselection
+        ca_atoms = self.mol_skipped.atomselect("protein and name CA", indexes=True)
+        metr = MetricSelfDistance(ca_atoms, metric="contacts", threshold=8)
+        data = metr.project(self.mol_skipped)
+        mapping = metr.getMapping(self.mol_skipped)
+        assert data.shape == (20, 38226) and mapping.shape == (38226, 3)
+
+        # Boolean atomselection
+        ca_atoms = self.mol_skipped.atomselect("protein and name CA")
+        metr = MetricSelfDistance(ca_atoms, metric="contacts", threshold=8)
+        data = metr.project(self.mol_skipped)
+        mapping = metr.getMapping(self.mol_skipped)
+        assert data.shape == (20, 38226) and mapping.shape == (38226, 3)
+
+        # Manual group atomselection with integers
+        ca_atoms = self.mol_skipped.atomselect("protein and name CA", indexes=True)
+        metr = MetricSelfDistance([ca_atoms[0::3], ca_atoms[1::3], ca_atoms[2::3]],)
+        data = metr.project(self.mol_skipped)
+        mapping = metr.getMapping(self.mol_skipped)
+        assert data.shape == (20, 3) and mapping.shape == (3, 3)
+
+        # Manual group atomselection with booleans
+        ca_atoms = self.mol_skipped.atomselect("protein and name CA", indexes=True)
+        ca_bools1 = self.mol_skipped.atomselect(
+            "index {}".format(" ".join(map(str, ca_atoms[0::3])))
+        )
+        ca_bools2 = self.mol_skipped.atomselect(
+            "index {}".format(" ".join(map(str, ca_atoms[1::3])))
+        )
+        ca_bools3 = self.mol_skipped.atomselect(
+            "index {}".format(" ".join(map(str, ca_atoms[2::3])))
+        )
+        metr = MetricSelfDistance([ca_bools1, ca_bools2, ca_bools3])
+        newdata = metr.project(self.mol_skipped)
+        mapping = metr.getMapping(self.mol_skipped)
+        assert (
+            newdata.shape == (20, 3)
+            and mapping.shape == (3, 3)
+            and np.array_equal(data, newdata)
+        )
+
     def test_distances_trivial(self):
         from moleculekit.molecule import Molecule
         import numpy as np
@@ -507,7 +605,7 @@ class _TestMetricDistance(unittest.TestCase):
 
         realdistances = np.linalg.norm(mol.coords[[1, 2], :, :], axis=1).T
 
-        metr = MetricDistance("index 0", "index 1 2", metric="distances", pbc=False)
+        metr = MetricDistance("index 0", "index 1 2", metric="distances", periodic=None)
         data = metr.project(mol)
         assert np.allclose(
             data, realdistances
@@ -518,7 +616,9 @@ class _TestMetricDistance(unittest.TestCase):
         wrappedrealdistances = np.linalg.norm(wrappedcoords[[1, 2], :, :], axis=1).T
 
         mol.box = np.full((3, 2), 2, dtype=np.float32)  # Make box 2x2x2A large
-        metr = MetricDistance("index 0", "index 1 2", metric="distances", pbc=True)
+        metr = MetricDistance(
+            "index 0", "index 1 2", metric="distances", periodic="selections"
+        )
         data = metr.project(mol)
         assert np.allclose(
             data, wrappedrealdistances
@@ -529,7 +629,7 @@ class _TestMetricDistance(unittest.TestCase):
             "index 0",
             "index 1 2",
             metric="distances",
-            pbc=False,
+            periodic=None,
             groupsel1="all",
             groupsel2="all",
         )
@@ -565,7 +665,9 @@ class _TestMetricDistance(unittest.TestCase):
             )
         )
 
-        metr = MetricDistance("index 0 1", "index 2 3", metric="distances", pbc=False)
+        metr = MetricDistance(
+            "index 0 1", "index 2 3", metric="distances", periodic=None
+        )
         data = metr.project(mol)
         assert np.allclose(
             data, realdistances
@@ -573,7 +675,10 @@ class _TestMetricDistance(unittest.TestCase):
 
     def test_distances(self):
         metr = MetricDistance(
-            "protein and name CA", "resname MOL and noh", metric="distances"
+            "protein and name CA",
+            "resname MOL and noh",
+            metric="distances",
+            periodic="selections",
         )
         data = metr.project(self.mol)
         refdata = np.load(
@@ -587,6 +692,7 @@ class _TestMetricDistance(unittest.TestCase):
         metr = MetricDistance(
             "protein and noh",
             "resname MOL and noh",
+            periodic="selections",
             groupsel1="residue",
             groupsel2="all",
         )
@@ -604,6 +710,7 @@ class _TestMetricDistance(unittest.TestCase):
         metr = MetricDistance(
             "protein and noh",
             "resname MOL and noh",
+            periodic="selections",
             groupsel1="residue",
             groupsel2="all",
             truncate=3,
@@ -622,6 +729,7 @@ class _TestMetricDistance(unittest.TestCase):
         metr = MetricDistance(
             "protein and resid 1 to 50 and noh",
             "protein and resid 1 to 50 and noh",
+            periodic=None,
             groupsel1="residue",
             groupsel2="residue",
         )
@@ -676,7 +784,7 @@ class _TestMetricDistance(unittest.TestCase):
 
         mol = Molecule("1yu8")
 
-        metr = MetricSelfDistance("protein and name CA", metric="contacts", pbc=False)
+        metr = MetricSelfDistance("protein and name CA", metric="contacts")
         data = metr.project(mol)[0]
         mapping = metr.getMapping(mol)
 
@@ -696,7 +804,9 @@ class _TestMetricDistance(unittest.TestCase):
         assert np.array_equal(refdata["uqAtomGroups"], uqAtomGroups)
 
     def test_description(self):
-        metr = MetricDistance("protein and noh", "resname MOL and noh", truncate=3)
+        metr = MetricDistance(
+            "protein and noh", "resname MOL and noh", truncate=3, periodic="selections"
+        )
         data = metr.project(self.mol)
         atomIndexes = metr.getMapping(self.mol).atomIndexes.values
         refdata = np.load(
@@ -707,6 +817,31 @@ class _TestMetricDistance(unittest.TestCase):
         )
         assert np.array_equal(refdata, atomIndexes)
 
+    def test_periodicity(self):
+        metr = MetricDistance(
+            "protein and resid 1 to 20 and noh",
+            "resname MOL and noh",
+            periodic="selections",
+        )
+        data1 = metr.project(self.mol)
+        metr = MetricDistance(
+            "protein and resid 1 to 20 and noh",
+            "resname MOL and noh",
+            periodic="chains",
+        )
+        data2 = metr.project(self.mol)
+        assert np.allclose(data1, data2)
+
+        mol_tmp = self.mol.copy()
+        mol_tmp.chain[:] = ""
+        metr = MetricDistance(
+            "protein and resid 1 to 20 and noh",
+            "resname MOL and noh",
+            periodic="chains",
+        )
+        data3 = metr.project(mol_tmp)
+        assert not np.allclose(data1, data3)
+
 
 if __name__ == "__main__":
     unittest.main(verbosity=2)
